@@ -6,7 +6,7 @@ CREATE SCHEMA IF NOT EXISTS pgstac;
 
 SET SEARCH_PATH TO pgstac, public;
 
-CREATE TABLE versions (
+CREATE TABLE migrations (
   version text,
   datetime timestamptz DEFAULT now() NOT NULL
 );
@@ -1183,4 +1183,4 @@ FROM j
 
 END;
 $$ LANGUAGE PLPGSQL SET SEARCH_PATH TO pgstac,public;
-INSERT INTO versions (version) ('0.1.9');
+INSERT INTO migrations (version) ('0.2.0');
