@@ -87,7 +87,9 @@ async def run_migration(dsn: str = None):
         logging.debug(f"Target database already at version: {version}")
         return version
     if oldversion is None:
-        logging.debug(f"No pgstac version set, installing {version} from scratch")
+        logging.debug(
+            f"No pgstac version set, installing {version} from scratch"
+        )
         migration_file = os.path.join(migrations_dir, f"pgstac.{version}.sql")
     else:
         logging.debug(f"Migrating from {oldversion} to {version}.")
@@ -108,7 +110,7 @@ async def run_migration(dsn: str = None):
             await conn.execute(migration_sql)
             await conn.execute(
                 """
-                INSERT INTO pgstac.versions (version)
+                INSERT INTO pgstac.migrations (version)
                 VALUES ($1);
                 """,
                 version,
@@ -136,12 +138,12 @@ class tables(str, Enum):
 
 async def aiter(list: List):
     for i in list:
-        logger.debug(orjson.dumps(i))
-        yield orjson.dumps(i) + b'\n'
+        yield orjson.dumps(i, option=orjson.OPT_APPEND_NEWLINE)
 
 
 async def copy(iter, table: tables, conn: asyncpg.Connection):
-    logging.debug(f"copying to {table} directly")
+    print(list(table))
+    logger.debug(f"copying to {table} directly")
     if isinstance(iter, List):
         logger.debug("Converting List into Async Iterator")
         iter = aiter(iter)
@@ -160,7 +162,7 @@ async def copy(iter, table: tables, conn: asyncpg.Connection):
 async def copy_ignore_duplicates(
     iter, table: tables, conn: asyncpg.Connection
 ):
-    logging.debug(f"inserting to {table} ignoring duplicates")
+    logger.debug(f"inserting to {table} ignoring duplicates")
     if isinstance(iter, List):
         logger.debug("Converting List into Async Iterator")
         iter = aiter(iter)
@@ -195,7 +197,7 @@ async def copy_ignore_duplicates(
 
 
 async def copy_upsert(iter, table: tables, conn: asyncpg.Connection):
-    logging.debug(f"upserting to {table}")
+    logger.debug(f"upserting to {table}")
     if isinstance(iter, List):
         logger.debug("Converting List into Async Iterator")
         iter = aiter(iter)
@@ -233,10 +235,11 @@ async def copy_upsert(iter, table: tables, conn: asyncpg.Connection):
 async def load_iterator(
     iter, table: tables, conn: asyncpg.Connection, method: loadopt = "insert"
 ):
+    logger.debug(f"Load Iterator Connection: {conn}")
     if method == "insert":
-        await copy(iter, tables, conn)
+        await copy(iter, table, conn)
     elif method == "insert_ignore":
-        await copy_ignore_duplicates(iter, tables, conn)
+        await copy_ignore_duplicates(iter, table, conn)
     else:
         await copy_upsert(iter, table, conn)
 
@@ -244,9 +247,10 @@ async def load_iterator(
 async def load_ndjson(
     file: str, table: tables, method: loadopt = "insert", dsn: str = None
 ):
+    print(f"loading {file} into {table} using {method}")
     with open(file, "rb") as f:
         async with DB(dsn) as conn:
-            await load_iterator(f, tables, conn, method)
+            await load_iterator(f, table, conn, method)
 
 
 @app.command()
